summaryrefslogtreecommitdiffstats
path: root/kopete/plugins/cryptography/kgpginterface.h
diff options
context:
space:
mode:
Diffstat (limited to 'kopete/plugins/cryptography/kgpginterface.h')
-rw-r--r--kopete/plugins/cryptography/kgpginterface.h24
1 files changed, 12 insertions, 12 deletions
diff --git a/kopete/plugins/cryptography/kgpginterface.h b/kopete/plugins/cryptography/kgpginterface.h
index b70bc68a..f324359e 100644
--- a/kopete/plugins/cryptography/kgpginterface.h
+++ b/kopete/plugins/cryptography/kgpginterface.h
@@ -26,8 +26,8 @@
/**
* Encrypt a file using gpg.
*/
-//class KgpgEncryptFile : public QObject {
-class KgpgInterface : public QObject {
+//class KgpgEncryptFile : public TQObject {
+class KgpgInterface : public TQObject {
Q_OBJECT
@@ -39,26 +39,26 @@ class KgpgInterface : public QObject {
/**Encrypt text function
* @param text QString text to be encrypted.
* @param userIDs the recipients key id's.
* @param Options String with the wanted gpg options. ex: "--armor"
* returns the encrypted text or empty string if encyption failed
*/
- static QString KgpgEncryptText(QString text,QString userIDs, QString Options="");
+ static TQString KgpgEncryptText(TQString text,TQString userIDs, TQString Options="");
/**Decrypt text function
* @param text QString text to be decrypted.
* @param userID QString the name of the decryption key (only used to prompt user for passphrase)
*/
- static QString KgpgDecryptText(QString text,QString userID);
-// static QString KgpgDecryptFileToText(KURL srcUrl,QString userID);
+ static TQString KgpgDecryptText(TQString text,TQString userID);
+// static TQString KgpgDecryptFileToText(KURL srcUrl,TQString userID);
/*
* Destructor for the class.
*/
~KgpgInterface();
- static QString checkForUtf8(QString txt);
+ static TQString checkForUtf8(TQString txt);
private slots:
@@ -69,12 +69,12 @@ signals:
/**
* @internal structure for communication
*/
- QString message,tempKeyFile,userIDs,txtprocess,output;
- QCString passphrase;
+ TQString message,tempKeyFile,userIDs,txtprocess,output;
+ TQCString passphrase;
bool deleteSuccess,konsLocal,anonymous,txtsent,decfinished,decok,badmdc;
int signSuccess;
int step,signb,sigsearch;
- QString konsSignKey, konsKeyID;
+ TQString konsSignKey, konsKeyID;
/**
@@ -39,26 +39,26 @@ class KgpgInterface : public QObject {
/**Encrypt text function
- * @param text QString text to be encrypted.
+ * @param text TQString text to be encrypted.
* @param userIDs the recipients key id's.
* @param Options String with the wanted gpg options. ex: "--armor"
@@ -39,26 +39,26 @@ class KgpgInterface : public QObject {
/**Decrypt text function
- * @param text QString text to be decrypted.
- * @param userID QString the name of the decryption key (only used to prompt user for passphrase)
+ * @param text TQString text to be decrypted.
+ * @param userID TQString the name of the decryption key (only used to prompt user for passphrase)
*/